% Auto-generated chapter 19 for tirmidhi
% Hadiths in this chapter: 31

\hadithdefcmd{tirmidhi}{1493}{حَدَّثَنَا أَبُو عَمْرٍو، مُسْلِمُ بْنُ عَمْرِو بْنِ مُسْلِمٍ الْحَذَّاءُ الْمَدَنِيُّ حَدَّثَنَا عَبْدُ اللَّهِ بْنُ نَافِعٍ الصَّائِغُ أَبُو مُحَمَّدٍ، عَنْ أَبِي الْمُثَنَّى، عَنْ هِشَامِ بْنِ عُرْوَةَ، عَنْ أَبِيهِ، عَنْ عَائِشَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏"‏ مَا عَمِلَ آدَمِيٌّ مِنْ عَمَلٍ يَوْمَ النَّحْرِ أَحَبَّ إِلَى اللَّهِ مِنْ إِهْرَاقِ الدَّمِ إِنَّهَا لَتَأْتِي يَوْمَ الْقِيَامَةِ بِقُرُونِهَا وَأَشْعَارِهَا وَأَظْلاَفِهَا وَإِنَّ الدَّمَ لَيَقَعُ مِنَ اللَّهِ بِمَكَانٍ قَبْلَ أَنْ يَقَعَ مِنَ الأَرْضِ فَطِيبُوا بِهَا نَفْسًا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عِمْرَانَ بْنِ حُصَيْنٍ وَزَيْدِ بْنِ أَرْقَمَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ هِشَامِ بْنِ عُرْوَةَ إِلاَّ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو الْمُثَنَّى اسْمُهُ سُلَيْمَانُ بْنُ يَزِيدَ ‏.‏ رَوَى عَنْهُ ابْنُ أَبِي فُدَيْكٍ ‏.‏ - قَالَ أَبُو عِيسَى وَيُرْوَى عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ فِي الأُضْحِيَةِ لِصَاحِبِهَا بِكُلِّ شَعَرَةٍ حَسَنَةٌ ‏"‏ ‏.‏ وَيُرْوَى ‏"‏ بِقُرُونِهَا ‏"‏ ‏.‏\hadithno{1493}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Aishah:That the Messenger of Allah (ﷺ) said: "A human does no action from the actions on the day of Nahr more beloved to Allah then spilling blood (of sacrificial animals). On the Day of Judgement, it will appear with its horns, and hair, and hooves, and indeed the blood will be accepted by Allah from where it is received before it even falls upon earth, so let your heart delight in it}}
\hadithdefcmd{tirmidhi}{1494}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِكَبْشَيْنِ أَمْلَحَيْنِ أَقْرَنَيْنِ ذَبَحَهُمَا بِيَدِهِ وَسَمَّى وَكَبَّرَ وَوَضَعَ رِجْلَهُ عَلَى صِفَاحِهِمَا ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَعَائِشَةَ وَأَبِي هُرَيْرَةَ وَأَبِي أَيُّوبَ وَجَابِرٍ وَأَبِي الدَّرْدَاءِ وَأَبِي رَافِعٍ وَابْنِ عُمَرَ وَأَبِي بَكْرَةَ أَيْضًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1494}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas bin Malik:"The Messenger of Allah (ﷺ) slaughtered two horned male sheep which were mostly white. He slaughtered them with his hand and mentioned Allah's Name, and he said 'Allahu Akbar', and put his foot on their side}}
\hadithdefcmd{tirmidhi}{1495}{حَدَّثَنَا مُحَمَّدُ بْنُ عُبَيْدٍ الْمُحَارِبِيُّ الْكُوفِيُّ، حَدَّثَنَا شَرِيكٌ، عَنْ أَبِي الْحَسْنَاءِ، عَنِ الْحَكَمِ، عَنْ حَنَشٍ، عَنْ عَلِيٍّ، أَنَّهُ كَانَ يُضَحِّي بِكَبْشَيْنِ أَحَدُهُمَا عَنِ النَّبِيِّ صلى الله عليه وسلم وَالآخَرُ عَنْ نَفْسِهِ، فَقِيلَ لَهُ فَقَالَ أَمَرَنِي بِهِ يَعْنِي النَّبِيَّ صلى الله عليه وسلم - فَلاَ أَدَعُهُ أَبَدًا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ شَرِيكٍ ‏.‏ وَقَدْ رَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ أَنْ يُضَحَّى عَنِ الْمَيِّتِ وَلَمْ يَرَ بَعْضُهُمْ أَنْ يُضَحَّى عَنْهُ ‏.‏ وَقَالَ عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ أَحَبُّ إِلَىَّ أَنْ يُتَصَدَّقَ عَنْهُ وَلاَ يُضَحَّى عَنْهُ وَإِنْ ضَحَّى فَلاَ يَأْكُلْ مِنْهَا شَيْئًا وَيَتَصَدَّقْ بِهَا كُلِّهَا ‏.‏ قَالَ مُحَمَّدٌ قَالَ عَلِيُّ بْنُ الْمَدِينِيِّ وَقَدْ رَوَاهُ غَيْرُ شَرِيكٍ ‏.‏ قُلْتُ لَهُ أَبُو الْحَسْنَاءِ مَا اسْمُهُ فَلَمْ يَعْرِفْهُ ‏.‏ قَالَ مُسْلِمٌ اسْمُهُ الْحَسَنُ ‏.‏\hadithno{1495}\hadithgrade{Zubair Ali Zai: Daif}\hadithtrans{Narrated Hanash:That 'Ali used to slaughter two male sheep, one for the Prophet (ﷺ) and the other for himself. When this was mentioned to him, he said: "He ordered me to" - meaning the Prophet (ﷺ) - "So I will never leave it}}
\hadithdefcmd{tirmidhi}{1496}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا حَفْصُ بْنُ غِيَاثٍ، عَنْ جَعْفَرِ بْنِ مُحَمَّدٍ، عَنْ أَبِيهِ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم بِكَبْشٍ أَقْرَنَ فَحِيلٍ يَأْكُلُ فِي سَوَادٍ وَيَمْشِي فِي سَوَادٍ وَيَنْظُرُ فِي سَوَادٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ حَفْصِ بْنِ غِيَاثٍ ‏.‏\hadithno{1496}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Sa'eed Al-Khudri:"The Messenger of Allah (ﷺ) slaughtered a horned male ram of fine pedigree, (around) his mouth was black, and his legs were black, and (around) his eyes was black}}
\hadithdefcmd{tirmidhi}{1497}{\hadithno{1497}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1498}{\hadithno{1498}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1499}{حَدَّثَنَا يُوسُفُ بْنُ عِيسَى، حَدَّثَنَا وَكِيعٌ، حَدَّثَنَا عُثْمَانُ بْنُ وَاقِدٍ، عَنْ كِدَامِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ أَبِي كِبَاشٍ، قَالَ جَلَبْتُ غَنَمًا جُذْعَانًا إِلَى الْمَدِينَةِ فَكَسَدَتْ عَلَىَّ فَلَقِيتُ أَبَا هُرَيْرَةَ فَسَأَلْتُهُ فَقَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ نِعْمَ - أَوْ نِعْمَتِ - الأُضْحِيَةُ الْجَذَعُ مِنَ الضَّأْنِ ‏"‏ ‏.‏ قَالَ فَانْتَهَبَهُ النَّاسُ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ عَبَّاسٍ وَأُمِّ بِلاَلٍ ابْنَةِ هِلاَلٍ عَنْ أَبِيهَا وَجَابِرٍ وَعُقْبَةَ بْنِ عَامِرٍ وَرَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ أَبِي هُرَيْرَةَ حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَقَدْ رُوِيَ هَذَا عَنْ أَبِي هُرَيْرَةَ مَوْقُوفًا ‏.‏ وَعُثْمَانُ بْنُ وَاقِدٍ هُوَ ابْنُ مُحَمَّدِ بْنِ زِيَادِ بْنِ عَبْدِ اللَّهِ بْنِ عُمَرَ بْنِ الْخَطَّابِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنَّ الْجَذَعَ مِنَ الضَّأْنِ يُجْزِئُ فِي الأُضْحِيَةِ ‏.‏\hadithno{1499}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Kibash:"I brought a Jadha' sheep to Al-Madinah (for sale) but it remained with me. I saw Abu Hurairah and I asked him about it, so he said: 'I heard the Messenger of Allah (ﷺ) saying: "The best male" - or - "female Udhiyah is that from the Jadha' sheep." He said: "So the people took note of that (they became interested in buying)}}
\hadithdefcmd{tirmidhi}{1500}{\hadithno{1500}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1501}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا الْفَضْلُ بْنُ مُوسَى، عَنِ الْحُسَيْنِ بْنِ وَاقِدٍ، عَنْ عِلْبَاءَ بْنِ أَحْمَرَ، عَنْ عِكْرِمَةَ، عَنِ ابْنِ عَبَّاسٍ، قَالَ كُنَّا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم فِي سَفَرٍ فَحَضَرَ الأَضْحَى فَاشْتَرَكْنَا فِي الْبَقَرَةِ سَبْعَةً وَفِي الْبَعِيرِ عَشَرَةً ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي الأَسْوَدِ السُّلَمِيِّ عَنْ أَبِيهِ عَنْ جَدِّهِ وَأَبِي أَيُّوبَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ الْفَضْلِ بْنِ مُوسَى ‏.‏\hadithno{1501}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Ibn 'Abbas:"We were with the Messenger of Allah (ﷺ) on a journey when the (Day of) Adha came, so we shared seven for a cow and ten for a camel}}
\hadithdefcmd{tirmidhi}{1502}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا مَالِكُ بْنُ أَنَسٍ، عَنْ أَبِي الزُّبَيْرِ، عَنْ جَابِرٍ، قَالَ نَحَرْنَا مَعَ رَسُولِ اللَّهِ صلى الله عليه وسلم بِالْحُدَيْبِيَةِ الْبَدَنَةَ عَنْ سَبْعَةٍ وَالْبَقَرَةَ عَنْ سَبْعَةٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ وَالشَّافِعِيِّ وَأَحْمَدَ وَإِسْحَاقَ ‏.‏ وَقَالَ إِسْحَاقُ يُجْزِئُ أَيْضًا الْبَعِيرُ عَنْ عَشَرَةٍ ‏.‏ وَاحْتَجَّ بِحَدِيثِ ابْنِ عَبَّاسٍ ‏.‏\hadithno{1502}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Jabir:"We performed the Nahr (sacrifice) with the Messenger of Allah (ﷺ) at Al-Hudaibiyyah: A camel for seven (persons) and a cow for seven (persons)}}
\hadithdefcmd{tirmidhi}{1503}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا شَرِيكٌ، عَنْ سَلَمَةَ بْنِ كُهَيْلٍ، عَنْ حُجَيَّةَ بْنِ عَدِيٍّ، عَنْ عَلِيٍّ، قَالَ الْبَقَرَةُ عَنْ سَبْعَةٍ، ‏.‏ قُلْتُ فَإِنْ وَلَدَتْ قَالَ اذْبَحْ وَلَدَهَا مَعَهَا ‏.‏ قُلْتُ فَالْعَرْجَاءُ قَالَ إِذَا بَلَغَتِ الْمَنْسِكَ ‏.‏ قُلْتُ فَمَكْسُورَةُ الْقَرْنِ قَالَ لاَ بَأْسَ أُمِرْنَا أَوْ أَمَرَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ نَسْتَشْرِفَ الْعَيْنَيْنِ وَالأُذُنَيْنِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رَوَاهُ سُفْيَانُ الثَّوْرِيُّ عَنْ سَلَمَةَ بْنِ كُهَيْلٍ ‏.‏\hadithno{1503}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Hujayyah bin 'Adi:"Ali said: 'A cow is for seven.' I said: "And if it gives birth?' He said: 'Then slaughter its offspring with it.' I said: 'What if it is lame?' He said: 'When it has reached the place of ritual.' I said: 'What if it has a broken horn?' He said: 'There is no harm, we were ordered' - or - 'The Messenger of Allah (ﷺ) ordered us, to check the two eyes and the two ears}}
\hadithdefcmd{tirmidhi}{1504}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا عَبْدَةُ، عَنْ سَعِيدٍ، عَنْ قَتَادَةَ، عَنْ جُرَىِّ بْنِ كُلَيْبٍ النَّهْدِيِّ، عَنْ عَلِيٍّ، قَالَ نَهَى رَسُولُ اللَّهِ صلى الله عليه وسلم أَنْ يُضَحَّى بِأَعْضَبِ الْقَرْنِ وَالأُذُنِ ‏.‏ قَالَ قَتَادَةُ فَذَكَرْتُ ذَلِكَ لِسَعِيدِ بْنِ الْمُسَيَّبِ فَقَالَ الْعَضْبُ مَا بَلَغَ النِّصْفَ فَمَا فَوْقَ ذَلِكَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1504}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated 'Ali:"The Messenger of Allah (ﷺ) prohibited that an animal with a A'dab (stump) horn or ear should be slaughtered as a sacrifice." Qatadah (one of the narrators) said: "So I mentioned this to Sa'eed bin Al-Musayyab and he said: 'The A'dab is that which equals or more than that}}
\hadithdefcmd{tirmidhi}{1505}{حَدَّثَنِي يَحْيَى بْنُ مُوسَى، حَدَّثَنَا أَبُو بَكْرٍ الْحَنَفِيُّ، حَدَّثَنَا الضَّحَّاكُ بْنُ عُثْمَانَ، حَدَّثَنِي عُمَارَةُ بْنُ عَبْدِ اللَّهِ، قَالَ سَمِعْتُ عَطَاءَ بْنَ يَسَارٍ، يَقُولُ سَأَلْتُ أَبَا أَيُّوبَ الأَنْصَارِيَّ كَيْفَ كَانَتِ الضَّحَايَا عَلَى عَهْدِ رَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ كَانَ الرَّجُلُ يُضَحِّي بِالشَّاةِ عَنْهُ وَعَنْ أَهْلِ بَيْتِهِ فَيَأْكُلُونَ وَيُطْعِمُونَ حَتَّى تَبَاهَى النَّاسُ فَصَارَتْ كَمَا تَرَى ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَعُمَارَةُ بْنُ عَبْدِ اللَّهِ هُوَ مَدَنِيٌّ وَقَدْ رَوَى عَنْهُ مَالِكُ بْنُ أَنَسٍ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ بَعْضِ أَهْلِ الْعِلْمِ وَهُوَ قَوْلُ أَحْمَدَ وَإِسْحَاقَ وَاحْتَجَّا بِحَدِيثِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ ضَحَّى بِكَبْشٍ فَقَالَ ‏ "‏ هَذَا عَمَّنْ لَمْ يُضَحِّ مِنْ أُمَّتِي ‏"‏ ‏.‏ وَقَالَ بَعْضُ أَهْلِ الْعِلْمِ لاَ تُجْزِئُ الشَّاةُ إِلاَّ عَنْ نَفْسٍ وَاحِدَةٍ وَهُوَ قَوْلُ عَبْدِ اللَّهِ بْنِ الْمُبَارَكِ وَغَيْرِهِ مِنْ أَهْلِ الْعِلْمِ ‏.‏\hadithno{1505}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Ata bin Yasar:"I asked Abu Abyub [Al-Ansari] how the slaughtering was done during the time of the Messenger of Allah (ﷺ). He said: 'A man would sacrifice a sheep for himself and the people in his household. They would eat from it and feed others, until the people (later) would boast about it and it became as you see now}}
\hadithdefcmd{tirmidhi}{1506}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا هُشَيْمٌ، أَخْبَرَنَا حَجَّاجُ بْنُ أَرْطَاةَ، عَنْ جَبَلَةَ بْنِ سُحَيْمٍ، أَنَّ رَجُلاً، سَأَلَ ابْنَ عُمَرَ عَنِ الأُضْحِيَةِ، أَوَاجِبَةٌ هِيَ فَقَالَ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْمُسْلِمُونَ ‏.‏ فَأَعَادَهَا عَلَيْهِ فَقَالَ أَتَعْقِلُ ضَحَّى رَسُولُ اللَّهِ صلى الله عليه وسلم وَالْمُسْلِمُونَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ أَنَّ الأُضْحِيَةَ لَيْسَتْ بِوَاجِبَةٍ وَلَكِنَّهَا سُنَّةٌ مِنْ سُنَنِ رَسُولِ اللَّهِ صلى الله عليه وسلم يُسْتَحَبُّ أَنْ يُعْمَلَ بِهَا وَهُوَ قَوْلُ سُفْيَانَ الثَّوْرِيِّ وَابْنِ الْمُبَارَكِ ‏.‏\hadithno{1506}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabalah bin Suhaim :That a man asked Ibn 'Umar about the Udhiyah, "Is it obligatory?" So he said: "The Messenger of Allah (ﷺ) performed the Udhiyah as did the Muslims." He repeated the question. So he said: "Do you understand ?" The Messenger of Allah (ﷺ) slaughtered as did the Muslims}}
\hadithdefcmd{tirmidhi}{1507}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، وَهَنَّادٌ، قَالاَ حَدَّثَنَا ابْنُ أَبِي زَائِدَةَ، عَنْ حَجَّاجِ بْنِ أَرْطَاةَ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، قَالَ أَقَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم بِالْمَدِينَةِ عَشْرَ سِنِينَ يُضَحِّي ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1507}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Ibn 'Umar :"The Messenger of Allah (ﷺ) stayed in Al-Madinah for ten years performing the Udhiyah}}
\hadithdefcmd{tirmidhi}{1508}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ إِبْرَاهِيمَ، عَنْ دَاوُدَ بْنِ أَبِي هِنْدٍ، عَنِ الشَّعْبِيِّ، عَنِ الْبَرَاءِ بْنِ عَازِبٍ، قَالَ خَطَبَنَا رَسُولُ اللَّهِ صلى الله عليه وسلم فِي يَوْمِ نَحْرٍ فَقَالَ ‏"‏ لاَ يَذْبَحَنَّ أَحَدُكُمْ حَتَّى يُصَلِّيَ ‏"‏ ‏.‏ قَالَ فَقَامَ خَالِي فَقَالَ يَا رَسُولَ اللَّهِ هَذَا يَوْمٌ اللَّحْمُ فِيهِ مَكْرُوهٌ وَإِنِّي عَجَّلْتُ نُسُكِي لأُطْعِمَ أَهْلِي وَأَهْلَ دَارِي أَوْ جِيرَانِي ‏.‏ قَالَ ‏"‏ فَأَعِدْ ذَبْحًا آخَرَ ‏"‏ ‏.‏ فَقَالَ يَا رَسُولَ اللَّهِ عِنْدِي عَنَاقُ لَبَنٍ وَهِيَ خَيْرٌ مِنْ شَاتَىْ لَحْمٍ أَفَأَذْبَحُهَا قَالَ ‏"‏ نَعَمْ وَهِيَ خَيْرُ نَسِيكَتَيْكَ وَلاَ تُجْزِئُ جَذَعَةٌ لأَحَدٍ بَعْدَكَ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ جَابِرٍ وَجُنْدَبٍ وَأَنَسٍ وَعُوَيْمِرِ بْنِ أَشْقَرَ وَابْنِ عُمَرَ وَأَبِي زَيْدٍ الأَنْصَارِيِّ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَكْثَرِ أَهْلِ الْعِلْمِ أَنْ لاَ يُضَحَّى بِالْمِصْرِ حَتَّى يُصَلِّيَ الإِمَامُ وَقَدْ رَخَّصَ قَوْمٌ مِنْ أَهْلِ الْعِلْمِ لأَهْلِ الْقُرَى فِي الذَّبْحِ إِذَا طَلَعَ الْفَجْرُ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ أَجْمَعَ أَهْلُ الْعِلْمِ أَنْ لاَ يُجْزِئَ الْجَذَعُ مِنَ الْمَعْزِ وَقَالُوا إِنَّمَا يُجْزِئُ الْجَذَعُ مِنَ الضَّأْنِ ‏.‏\hadithno{1508}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Al-Bara' bin 'Azib :"The Messenger of Allah (ﷺ) delivered a sermon to us on the Day of Nahr and he said: 'None of you should slaughter until he performs the Salat." He said: 'So my maternal uncle stood and said: ' O Messenger of Allah, this is the day in which meat is disliked, and I hastened my sacrifice to feed my family and the people of my dwellings - or - 'my neighbors.' He said: 'Repeat your slaughter with another.' He said: 'O Messenger of Allah (ﷺ) I have a she-kid that has better meat than my sheep, should I slaughter it?' He said: 'Yes, and it is better and it will suffice for you, but a Jadha' will not be accepted after you}}
\hadithdefcmd{tirmidhi}{1509}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنْ نَافِعٍ، عَنِ ابْنِ عُمَرَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لاَ يَأْكُلُ أَحَدُكُمْ مِنْ لَحْمِ أُضْحِيَتِهِ فَوْقَ ثَلاَثَةِ أَيَّامٍ ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَائِشَةَ وَأَنَسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ ابْنِ عُمَرَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ - وَإِنَّمَا كَانَ النَّهْىُ مِنَ النَّبِيِّ صلى الله عليه وسلم مُتَقَدِّمًا ثُمَّ رَخَّصَ بَعْدَ ذَلِكَ ‏.‏\hadithno{1509}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Ibn 'Umar:That the Prophet (ﷺ) said: "None of you should eat from the meat of his sacrificial animal beyond three days}}
\hadithdefcmd{tirmidhi}{1510}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَمَحْمُودُ بْنُ غَيْلاَنَ، وَالْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، وَغَيْرُ، وَاحِدٍ، قَالُوا أَخْبَرَنَا أَبُو عَاصِمٍ النَّبِيلُ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، عَنْ عَلْقَمَةَ بْنِ مَرْثَدٍ، عَنْ سُلَيْمَانَ بْنِ بُرَيْدَةَ، عَنْ أَبِيهِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ كُنْتُ نَهَيْتُكُمْ عَنْ لُحُومِ الأَضَاحِي فَوْقَ ثَلاَثٍ لِيَتَّسِعَ ذُو الطَّوْلِ عَلَى مَنْ لاَ طَوْلَ لَهُ فَكُلُوا مَا بَدَا لَكُمْ وَأَطْعِمُوا وَادَّخِرُوا ‏"‏ ‏.‏ قَالَ وَفِي الْبَابِ عَنِ ابْنِ مَسْعُودٍ وَعَائِشَةَ وَنُبَيْشَةَ وَأَبِي سَعِيدٍ وَقَتَادَةَ بْنِ النُّعْمَانِ وَأَنَسٍ وَأُمِّ سَلَمَةَ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ بُرَيْدَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ ‏.‏\hadithno{1510}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Sulaiman bin Buraidah:From his father that the Messenger of Allah (ﷺ) said: "I used to prohibit you from (eating) the meat of Sacrifice beyond three days so that those who have the ability would give to those who do not have it. So (now) eat as you like, feed others, and save from it}}
\hadithdefcmd{tirmidhi}{1511}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا أَبُو الأَحْوَصِ، عَنْ أَبِي إِسْحَاقَ، عَنْ عَابِسِ بْنِ رَبِيعَةَ، قَالَ قُلْتُ لأُمِّ الْمُؤْمِنِينَ أَكَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَنْهَى عَنْ لُحُومِ الأَضَاحِي قَالَتْ لاَ وَلَكِنْ قَلَّ مَنْ كَانَ يُضَحِّي مِنَ النَّاسِ فَأَحَبَّ أَنْ يُطْعَمَ مَنْ لَمْ يَكُنْ يُضَحِّي وَلَقَدْ كُنَّا نَرْفَعُ الْكُرَاعَ فَنَأْكُلُهُ بَعْدَ عَشَرَةِ أَيَّامٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأُمُّ الْمُؤْمِنِينَ هِيَ عَائِشَةُ زَوْجُ النَّبِيِّ صلى الله عليه وسلم وَقَدْ رُوِيَ عَنْهَا هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ ‏.‏\hadithno{1511}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated 'Abis bin Rabi'ah:"I said to the Mother of the Believers: 'Did the Messenger of Allah (ﷺ) prohibit from the meat of the sacrifice?' She said: 'No, but only a few people could slaughter, so he liked that they feed those who did not slaughter. (Later) we would store a leg to eat after ten days}}
\hadithdefcmd{tirmidhi}{1512}{حَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، أَخْبَرَنَا مَعْمَرٌ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ الْمُسَيَّبِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ فَرَعَ وَلاَ عَتِيرَةَ ‏"‏ ‏.‏ وَالْفَرَعُ أَوَّلُ النِّتَاجِ كَانَ يُنْتَجُ لَهُمْ فَيَذْبَحُونَهُ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ نُبَيْشَةَ وَمِخْنَفِ بْنِ سُلَيْمٍ وَأَبِي الْعُشَرَاءِ عَنْ أَبِيهِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَتِيرَةُ ذَبِيحَةٌ كَانُوا يَذْبَحُونَهَا فِي رَجَبٍ يُعَظِّمُونَ شَهْرَ رَجَبٍ لأَنَّهُ أَوَّلُ شَهْرٍ مِنْ أَشْهُرِ الْحُرُمِ وَأَشْهُرُ الْحُرُمِ رَجَبٌ وَذُو الْقَعْدَةِ وَذُو الْحِجَّةِ وَالْمُحَرَّمُ وَأَشْهُرُ الْحَجِّ شَوَّالٌ وَذُو الْقَعْدَةِ وَعَشْرٌ مِنْ ذِي الْحِجَّةِ كَذَلِكَ رُوِيَ عَنْ بَعْضِ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ فِي أَشْهُرِ الْحَجِّ.‏\hadithno{1512}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Hurairah:That the Messenger of Allah (ﷺ) said: "There is no Fara' or 'Atirah." The Fara' is the first of the offspring that would be born to them, so they would slaughter it. The 'Atirah was an animal that they would slaughter during Rajab to honor the month of Rajab, since it was the first of the sacred months}}
\hadithdefcmd{tirmidhi}{1513}{حَدَّثَنَا أَبُو سَلَمَةَ، يَحْيَى بْنُ خَلَفٍ الْبَصْرِيُّ حَدَّثَنَا بِشْرُ بْنُ الْمُفَضَّلِ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ عُثْمَانَ بْنِ خُثَيْمٍ، عَنْ يُوسُفَ بْنِ مَاهَكَ، أَنَّهُمْ دَخَلُوا عَلَى حَفْصَةَ بِنْتِ عَبْدِ الرَّحْمَنِ فَسَأَلُوهَا عَنِ الْعَقِيقَةِ، فَأَخْبَرَتْهُمْ أَنَّ عَائِشَةَ أَخْبَرَتْهَا أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم أَمَرَهُمْ عَنِ الْغُلاَمِ شَاتَانِ مُكَافِئَتَانِ وَعَنِ الْجَارِيَةِ شَاةٌ ‏.‏ قَالَ وَفِي الْبَابِ عَنْ عَلِيٍّ وَأُمِّ كُرْزٍ وَبُرَيْدَةَ وَسَمُرَةَ وَأَبِي هُرَيْرَةَ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو وَأَنَسٍ وَسَلْمَانَ بْنِ عَامِرٍ وَابْنِ عَبَّاسٍ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ عَائِشَةَ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَحَفْصَةُ هِيَ بِنْتُ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرٍ الصِّدِّيقِ ‏.‏\hadithno{1513}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Yusuf bin Mahak:They entered upon Hafsah bint 'Abdur-Rahman to ask her about the 'Aqiqah. She informed them that 'Aishah had informed her, that the Messenger of Allah (ﷺ) ordered them that for a boy, two sheep were sufficient, and for a girl one sheep}}
\hadithdefcmd{tirmidhi}{1514}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، وَعَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، قَالاَ أَخْبَرَنَا سُفْيَانُ، عَنْ عَاصِمِ بْنِ عُبَيْدِ اللَّهِ، عَنْ عُبَيْدِ اللَّهِ بْنِ أَبِي رَافِعٍ، عَنْ أَبِيهِ، قَالَ رَأَيْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم أَذَّنَ فِي أُذُنِ الْحَسَنِ بْنِ عَلِيٍّ حِينَ وَلَدَتْهُ فَاطِمَةُ بِالصَّلاَةِ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالْعَمَلُ عِنْدَ أَهْلِ الْعِلْمِ فِي الْعَقِيقَةِ عَلَى مَا رُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ وَجْهٍ عَنِ الْغُلاَمِ شَاتَانِ مُكَافِئَتَانِ وَعَنِ الْجَارِيَةِ شَاةٌ ‏.‏ - وَرُوِيَ عَنِ النَّبِيِّ صلى الله عليه وسلم أَيْضًا أَنَّهُ عَقَّ عَنِ الْحَسَنِ بِشَاةٍ وَقَدْ ذَهَبَ بَعْضُ أَهْلِ الْعِلْمِ إِلَى هَذَا الْحَدِيثِ ‏.‏\hadithno{1514}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated 'Ubaidullah bin Abi Rafi':That his father said: "I saw the Messenger of Allah (ﷺ) say the Adhan in the ear of Al-Hasan bin 'Ali - when he was born to Fatimah - the Adhan of Salat}}
\hadithdefcmd{tirmidhi}{1515}{\hadithno{1515}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1516}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا عَبْدُ الرَّزَّاقِ، عَنِ ابْنِ جُرَيْجٍ، أَخْبَرَنَا عُبَيْدُ اللَّهِ بْنُ أَبِي يَزِيدَ، عَنْ سِبَاعِ بْنِ ثَابِتٍ، أَنَّ مُحَمَّدَ بْنَ ثَابِتِ بْنِ سِبَاعٍ، أَخْبَرَهُ أَنَّ أُمَّ كُرْزٍ أَخْبَرَتْهُ أَنَّهَا، سَأَلَتْ رَسُولَ اللَّهِ صلى الله عليه وسلم عَنِ الْعَقِيقَةِ فَقَالَ ‏ "‏ عَنِ الْغُلاَمِ شَاتَانِ وَعَنِ الْجَارِيَةِ وَاحِدَةٌ وَلاَ يَضُرُّكُمْ ذُكْرَانًا كُنَّ أَمْ إِنَاثًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1516}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Umm Kurz:That she asked the Messenger of Allah (ﷺ) about the 'Aqiqah. He said: "For the boy is two sheep, and for the girl is one, it will not harm you if they (i.e. the sheep) are male or female}}
\hadithdefcmd{tirmidhi}{1517}{حَدَّثَنَا سَلَمَةُ بْنُ شَبِيبٍ، حَدَّثَنَا أَبُو الْمُغِيرَةِ، عَنْ عُفَيْرِ بْنِ مَعْدَانَ، عَنْ سُلَيْمِ بْنِ عَامِرٍ، عَنْ أَبِي أُمَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ خَيْرُ الأُضْحِيَةِ الْكَبْشُ وَخَيْرُ الْكَفَنِ الْحُلَّةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ ‏.‏ وَعُفَيْرُ بْنُ مَعْدَانَ يُضَعَّفُ فِي الْحَدِيثِ ‏.‏\hadithno{1517}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Umamah:That the Messenger of Allah (ﷺ) said: "The best of Udhiyah (sacrifice) is a ram, and the best (burial) shroud is the Hullah}}
\hadithdefcmd{tirmidhi}{1518}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ عَوْنٍ، حَدَّثَنَا أَبُو رَمْلَةَ، عَنْ مِخْنَفِ بْنِ سُلَيْمٍ، قَالَ كُنَّا وُقُوفًا مَعَ النَّبِيِّ صلى الله عليه وسلم بِعَرَفَاتٍ فَسَمِعْتُهُ يَقُولُ ‏ "‏ يَا أَيُّهَا النَّاسُ عَلَى كُلِّ أَهْلِ بَيْتٍ فِي كُلِّ عَامٍ أُضْحِيَةٌ وَعَتِيرَةٌ هَلْ تَدْرُونَ مَا الْعَتِيرَةُ هِيَ الَّتِي تُسَمُّونَهَا الرَّجَبِيَّةَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَلاَ نَعْرِفُ هَذَا الْحَدِيثَ إِلاَّ مِنْ هَذَا الْوَجْهِ مِنْ حَدِيثِ ابْنِ عَوْنٍ ‏.‏\hadithno{1518}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Mikhnaf bin Sulaim:"We were standing with the Prophet (ﷺ) at 'Arafat when I heard him say: 'O you people! For every household each year is Udhiyah (sacrifice) and 'Atirah. Do you know what an 'Atirah is ? It is that which you call Ar-Rajabiyyah}}
\hadithdefcmd{tirmidhi}{1519}{حَدَّثَنَا مُحَمَّدُ بْنُ يَحْيَى الْقُطَعِيُّ، حَدَّثَنَا عَبْدُ الأَعْلَى بْنُ عَبْدِ الأَعْلَى، عَنْ مُحَمَّدِ بْنِ إِسْحَاقَ، عَنْ عَبْدِ اللَّهِ بْنِ أَبِي بَكْرٍ، عَنْ مُحَمَّدِ بْنِ عَلِيِّ بْنِ الْحُسَيْنِ، عَنْ عَلِيِّ بْنِ أَبِي طَالِبٍ، قَالَ عَقَّ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الْحَسَنِ بِشَاةٍ وَقَالَ ‏ "‏ يَا فَاطِمَةُ احْلِقِي رَأْسَهُ وَتَصَدَّقِي بِزِنَةِ شَعْرِهِ فِضَّةً ‏"‏ ‏.‏ قَالَ فَوَزَنَتْهُ فَكَانَ وَزْنُهُ دِرْهَمًا أَوْ بَعْضَ دِرْهَمٍ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ وَإِسْنَادُهُ لَيْسَ بِمُتَّصِلٍ ‏.‏ وَأَبُو جَعْفَرٍ مُحَمَّدُ بْنُ عَلِيِّ بْنِ الْحُسَيْنِ لَمْ يُدْرِكْ عَلِيَّ بْنَ أَبِي طَالِبٍ ‏.‏\hadithno{1519}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Daif}\hadithtrans{Narrated Muhammad bin 'Ali bin Al-Husain:That Ali bin Abi Talib said: "The Messenger of Allah (ﷺ) had the 'Aqiqah for Al-Hasan with one sheep, and said: 'O Fatimah! Shave his head and give the weight of his hair in silver as charity.'" He said: "So I weighed it, and it was the weight of a Dirham or a bit of a Dirham}}
\hadithdefcmd{tirmidhi}{1520}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا أَزْهَرُ بْنُ سَعْدٍ السَّمَّانُ، عَنِ ابْنِ عَوْنٍ، عَنْ مُحَمَّدِ بْنِ سِيرِينَ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ أَبِي بَكْرَةَ، عَنْ أَبِيهِ، أَنَّ النَّبِيَّ صلى الله عليه وسلم خَطَبَ ثُمَّ نَزَلَ فَدَعَا بِكَبْشَيْنِ فَذَبَحَهُمَا ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1520}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated 'Abdur-Rahman bin Abi Bakrah:From his father, that the Prophet (ﷺ) gave a Khutbah, then he descended and called for two rams and slaughtered them}}
\hadithdefcmd{tirmidhi}{1521}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا يَعْقُوبُ بْنُ عَبْدِ الرَّحْمَنِ، عَنْ عَمْرِو بْنِ أَبِي عَمْرٍو، عَنِ الْمُطَّلِبِ، عَنْ جَابِرِ بْنِ عَبْدِ اللَّهِ، قَالَ شَهِدْتُ مَعَ النَّبِيِّ صلى الله عليه وسلم الأَضْحَى بِالْمُصَلَّى فَلَمَّا قَضَى خُطْبَتَهُ نَزَلَ عَنْ مِنْبَرِهِ فَأُتِيَ بِكَبْشٍ فَذَبَحَهُ رَسُولُ اللَّهِ صلى الله عليه وسلم بِيَدِهِ وَقَالَ ‏ "‏ بِسْمِ اللَّهِ وَاللَّهُ أَكْبَرُ هَذَا عَنِّي وَعَمَّنْ لَمْ يُضَحِّ مِنْ أُمَّتِي ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَالْعَمَلُ عَلَى هَذَا عِنْدَ أَهْلِ الْعِلْمِ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَغَيْرِهِمْ أَنْ يَقُولَ الرَّجُلُ إِذَا ذَبَحَ بِسْمِ اللَّهِ وَاللَّهُ أَكْبَرُ وَهُوَ قَوْلُ ابْنِ الْمُبَارَكِ ‏.‏ وَالْمُطَّلِبُ بْنُ عَبْدِ اللَّهِ بْنِ حَنْطَبٍ يُقَالُ إِنَّهُ لَمْ يَسْمَعْ مِنْ جَابِرٍ ‏.‏\hadithno{1521}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Jabir bin 'Abdullah:"I attended the Eid Al-Adha' with the Prophet (ﷺ) at the Musalla. When he finished his Khutbah, he descended from his Minbar and was given a male sheep. The Messenger of Allah (ﷺ) slaughtered it with his hand and said: 'Bismillah, Wa Allahu Akbar, this from me and whoever does not slaughter from my Ummah}}
\hadithdefcmd{tirmidhi}{1522}{\hadithno{1522}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1523}{حَدَّثَنَا أَحْمَدُ بْنُ الْحَكَمِ الْبَصْرِيُّ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، عَنْ شُعْبَةَ، عَنْ مَالِكِ بْنِ أَنَسٍ، عَنْ عَمْرٍو، أَوْ عُمَرَ بْنِ مُسْلِمٍ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ، عَنْ أُمِّ سَلَمَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ رَأَى هِلاَلَ ذِي الْحِجَّةِ وَأَرَادَ أَنْ يُضَحِّيَ فَلاَ يَأْخُذَنَّ مِنْ شَعْرِهِ وَلاَ مِنْ أَظْفَارِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَالصَّحِيحُ هُوَ عَمْرُو بْنُ مُسْلِمٍ قَدْ رَوَى عَنْهُ مُحَمَّدُ بْنُ عَمْرِو بْنِ عَلْقَمَةَ وَغَيْرُ وَاحِدٍ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ سَعِيدِ بْنِ الْمُسَيَّبِ عَنْ أُمِّ سَلَمَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم مِنْ غَيْرِ هَذَا الْوَجْهِ نَحْوَ هَذَا ‏.‏ وَهُوَ قَوْلُ بَعْضِ أَهْلِ الْعِلْمِ وَبِهِ كَانَ يَقُولُ سَعِيدُ بْنُ الْمُسَيَّبِ وَإِلَى هَذَا الْحَدِيثِ ذَهَبَ أَحْمَدُ وَإِسْحَاقُ ‏.‏ وَرَخَّصَ بَعْضُ أَهْلِ الْعِلْمِ فِي ذَلِكَ فَقَالُوا لاَ بَأْسَ أَنْ يَأْخُذَ مِنْ شَعْرِهِ وَأَظْفَارِهِ ‏.‏ وَهُوَ قَوْلُ الشَّافِعِيِّ وَاحْتَجَّ بِحَدِيثِ عَائِشَةَ أَنَّ النَّبِيَّ صلى الله عليه وسلم كَانَ يَبْعَثُ بِالْهَدْىِ مِنَ الْمَدِينَةِ فَلاَ يَجْتَنِبُ شَيْئًا مِمَّا يَجْتَنِبُ مِنْهُ الْمُحْرِمُ ‏.‏\hadithno{1523}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Umm Salamah:That the Prophet (ﷺ) said: "Whoever sees the crescent of Dhul-Hijjah, and wants to slaughter a sacrifice he should not take from his hair nor from his nails}}
